---
delivery_guarantee: "at_least_once"
description: "The Vector `splunk_hec` source ingests data through the Splunk HTTP Event Collector protocol and outputs `log` events."
event_types: ["log"]
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22source%3A+splunk_hec%22
operating_systems: ["linux","macos","windows"]
sidebar_label: "splunk_hec|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/sources/splunk_hec.rs
status: "beta"
title: "Splunk HEC Source"
unsupported_operating_systems: []
---

The Vector `splunk_hec` source ingests data through the [Splunk HTTP Event Collector protocol][urls.splunk_hec_protocol] and outputs [`log`][docs.data-model.log] events.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sources/splunk_hec.md.erb
-->

## Configuration

import CodeHeader from '@site/src/components/CodeHeader';

<CodeHeader fileName="vector.toml" learnMoreUrl="/docs/setup/configuration/"/ >

```toml
[sources.my_source_id]
  # REQUIRED
  type = "splunk_hec" # must be: "splunk_hec"

  # OPTIONAL
  address = "0.0.0.0:8088" # default
  token = "A94A8FE5CCB19BA61C4C08" # example, no default
```

## Options

import Fields from '@site/src/components/Fields';

import Field from '@site/src/components/Field';

<Fields filters={true}>


<Field
  common={true}
  defaultValue={"0.0.0.0:8088"}
  enumValues={null}
  examples={["0.0.0.0:8088"]}
  name={"address"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### address

The address to accept connections on.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["A94A8FE5CCB19BA61C4C08"]}
  name={"token"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

### token

If supplied, incoming requests must supply this token in the `Authorization` header, just as a client would if it was communicating with the Splunk HEC endpoint directly. If _not_ supplied, the `Authorization` header will be ignored and requests will not be authenticated.


</Field>


</Fields>

## Output

The `splunk_hec` source ingests data through the [Splunk HTTP Event Collector protocol][urls.splunk_hec_protocol] and outputs [`log`][docs.data-model.log] events.
For example:


Given the following input:

```text
Hello world
```

A log event will be output with the following structure:

```json
{
  "timestamp": <2019-07-26T20:30:27.000443Z>, // time event was received,
  "host": "my.host.com", // value of the `Host` header
  "splunk_channel": "FE0ECFAD-13D5-401B-847D-77833BD77131" // value of the `X-Splunk-Request-Channel` header

}
```

More detail on the output schema is below.

<Fields filters={true}>


<Field
  defaultValue={null}
  enumValues={null}
  examples={["Started GET / for 127.0.0.1 at 2012-03-10 14:28:14 +0100"]}
  name={"message"}
  path={null}
  required={true}
  type={"string"}
  >

### message

The raw log message, unaltered.


</Field>


<Field
  defaultValue={null}
  enumValues={null}
  examples={["2019-11-01T21:15:47+00:00"]}
  name={"splunk_channel"}
  path={null}
  required={true}
  type={"timestamp"}
  >

### splunk_channel

The Splunk channel, value of the `X-Splunk-Request-Channel` header.


</Field>


<Field
  defaultValue={null}
  enumValues={null}
  examples={["2019-11-01T21:15:47+00:00"]}
  name={"timestamp"}
  path={null}
  required={true}
  type={"timestamp"}
  >

### timestamp

If the [Splunk HEC event endpoint][urls.splunk_hec_event_endpoint] is used then the value of the [`time`](#time) field will be used. If the [Splunk HEC raw endpoint][urls.splunk_hec_raw_endpoint] is used, then the current time the event was received will be used.


</Field>


</Fields>

## How It Works

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[urls.splunk_hec_event_endpoint]: https://docs.splunk.com/Documentation/Splunk/8.0.0/RESTREF/RESTinput#services.2Fcollector.2Fevent
[urls.splunk_hec_protocol]: https://docs.splunk.com/Documentation/Splunk/8.0.0/Data/HECRESTendpoints
[urls.splunk_hec_raw_endpoint]: https://docs.splunk.com/Documentation/Splunk/8.0.0/RESTREF/RESTinput#services.2Fcollector.2Fraw
