---
title: Install Vector From Source
sidebar_label: From Source
description: Install Vector from the Vector source code
---

This page covers installing Vector from source using the native toolchain for the host.

Vector can also be compiled to a static binary for Linux for `x86_64`, `ARM64`,
and `ARMv7` architectures. See [compiling using Docker](#compiling-using-docker)
for details.

import Alert from '@site/src/components/Alert';

<Alert type="warning">

We recommend installing Vector through a supported [container
platform][docs.containers], [package manager][docs.package_managers], or
pre-built [archive][docs.from_archives], if possible. These handle permissions,
directory creation, and other intricacies covered in the [Next
Steps](#next-steps) section.

</Alert>

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/setup/installation/manual/from-source.md.erb
-->

## Installation

import Tabs from '@theme/Tabs';

1.  Install Rust

    ```bash
    curl --proto '=https' --tlsv1.2 -sSf https://sh.rustup.rs | sh -s -- -y --default-toolchain stable
    ```

2.  Install C and C++ compilers (GCC or Clang) and GNU `make` if they are not pre-installed
    on your system.

3.  Create the `vector` directory

    ```bash
    mkdir vector
    ```

4.  Download Vector's Source

    <Tabs
      className="mini"
      defaultValue="latest"
      values={[
        { label: 'Latest (0.7.0)', value: 'latest'},
        { label: 'Master', value: 'master'},
      ]}>

    import TabItem from '@theme/TabItem';

    <TabItem value="latest">

    ```bash
    mkdir -p vector && \
      curl -sSfL --proto '=https' --tlsv1.2 https://api.github.com/repos/timberio/vector/tarball/v0.7.X | \
      tar xzf - -C vector --strip-components=1
    ```

    </TabItem>
    <TabItem value="master">

    ```bash
    mkdir -p vector && \
      curl -sSfL --proto '=https' --tlsv1.2 https://github.com/timberio/vector/archive/master.tar.gz | \
      tar xzf - -C vector --strip-components=1
    ```

    </TabItem>
    </Tabs>

5.  Change into the `vector` directory

    ```bash
    cd vector
    ```

6.  Compile Vector

    ```bash
    [FEATURES="<flag1>,<flag2>,..."] make build
    ```

    The `FEATURES` environment variable is optional. You can override the
    default features with this variable. See [feature flags](#feature-flags)
    for more info.

    When finished, the vector binary will be placed in `target/<target>/release/vector`.
    For example, if you are building Vector on your Mac, your target triple
    is `x86_64-apple-darwin`, and the Vector binary will be located at
    `target/x86_64-apple-darwin/release/vector`.

7.  Start Vector

    Finally, start vector:

    ```bash
    target/<target>/release/vector --config config/vector.toml
    ```

## Next Steps

### Configuring

The Vector configuration file is located at:

```
config/vector.toml
```

A full spec is located at `config/vector.spec.toml` and examples are
located in `config/vector/examples/*`. You can learn more about configuring
Vector in the [Configuration][docs.configuration] section.

### Data Directory

We highly recommend creating a [data directory][docs.global-options#data-directory]
that Vector can use:

```
mkdir /var/lib/vector
```

<Alert type="warning">

Make sure that this directory is writable by the `vector` process.

</Alert>

Vector offers a global [`data_dir` option][docs.global-options#data_dir] that
you can use to specify the path of your directory.

import CodeHeader from '@site/src/components/CodeHeader';

<CodeHeader fileName="vector.toml" />

```toml
data_dir = "/var/lib/vector" # default
```

### Service Managers

Vector archives ship with service files in case you need them:

#### Init.d

To install Vector into Init.d run:

```bash
cp -av distribution/init.d/vector /etc/init.d
```

#### Systemd

To install Vector into Systemd run:

```bash
cp -av distribution/systemd/vector.service /etc/systemd/system
```

### Updating

Simply follow the same [installation instructions above](#installation).

## How It Works

### Feature Flags

The following feature flags are supported via the `FEATURES` env var when
executing `make build`:

```bash
[FEATURES="<flag1>,<flag2>,..."] make build
```

There are three meta-features which can be used when compiling for the corresponding targets. If no features
are specified, then the `default` one is used.

| Feature | Description | Enabled by default |
| :------ | :---------- | :----------------- |
| `default` | Default set of features for `*-unknown-linux-gnu` and `*-apple-darwin` targets. | <i className="feather icon-check"></i> |
| `default-musl` | Default set of features for `*-unknown-linux-musl` targets. Requires `cmake` and `perl` as build dependencies. | |
| `default-msvc` | Default set of features for `*-pc-windows-msvc` targets. Requires `cmake` and `perl` as build dependencies. | |

Alternatively, for finer control, it is possible to use specific features from the list below:

| Feature | Description | Included in `default` feature |
| :------ | :---------- | :----------------- |
| `unix` | Enables features that require `cfg(unix)` to be present on the platform, namely support for Unix domain sockets in [docker][docs.sources.docker] source and [jemalloc][urls.jemalloc] instead of the default memory allocator. | <i className="feather icon-check"></i> |
| `vendored` | Forces vendoring of [OpenSSL][urls.openssl] and [ZLib][urls.zlib] dependencies instead of using their versions installed in the system. Requires `perl` as a build dependency. | <i className="feather icon-check"></i>|
| `leveldb-plain` | Enables support for [disk buffers][docs.glossary#buffer] using vendored [LevelDB][urls.leveldb]. | <i className="feather icon-check"></i> |
| `leveldb-cmake` | The same as `leveldb-plain`, but is more portable. Requires `cmake` as a build dependency. Use it in case of compilation issues with `leveldb-plain`. | |
| `rdkafka-plain` | Enables vendored [librdkafka][urls.lib_rdkafka] dependency, which is required for [`kafka` source][docs.sources.kafka] and [`kafka` sink][docs.sources.kafka]. | <i className="feather icon-check"></i> |
| `rdkafka-cmake` | The same as `rdkafka-plain`, but is more portable. Requires `cmake` as a build dependency. Use it in case of compilation issues with `rdkafka-plain`. | |

## Compiling using Docker

It is possible to build statically linked binaries of Vector for Linux using Docker.

In this case the dependencies listed in the previous section are not
needed, as all of them would be automatically pulled by Docker.

Building steps:

1.  Download Vector's Source

    <Tabs
      className="mini"
      defaultValue="latest"
      values={[
        { label: 'Latest (0.7.0)', value: 'latest'},
        { label: 'Master', value: 'master'},
      ]}>

    <TabItem value="latest">

    ```bash
    mkdir -p vector && \
      curl -sSfL --proto '=https' --tlsv1.2 https://api.github.com/repos/timberio/vector/tarball/v0.7.X | \
      tar xzf - -C vector --strip-components=1
    ```

    </TabItem>
    <TabItem value="master">

    ```bash
    mkdir -p vector && \
      curl -sSfL --proto '=https' --tlsv1.2 https://github.com/timberio/vector/archive/master.tar.gz | \
      tar xzf - -C vector --strip-components=1
    ```

    </TabItem>
    </Tabs>

2. Build Vector using Docker
  <Tabs
    defaultValue="x86_64-unknown-linux-musl"
    urlKey="file_name"
    values={
    [{
      "label":"Linux (x86_64)",
      "value":"x86_64-unknown-linux-musl"
    }, {
      "label":"Linux (ARM64)",
      "value":"aarch64-unknown-linux-musl"
    },{
      "label":"Linux (ARMv7)",
      "value":"armv7-unknown-linux-musleabihf"
    }]
    }>

    <TabItem value="x86_64-unknown-linux-musl">

    ```bash
    PASS_FEATURES=default-musl ./scripts/docker-run.sh builder-x86_64-unknown-linux-musl make build
    ```

    </TabItem>

    <TabItem value="aarch64-unknown-linux-musl">

    ```bash
    PASS_FEATURES=default-musl ./scripts/docker-run.sh builder-aarch64-unknown-linux-musl make build
    ```

    </TabItem>

    <TabItem value="armv7-unknown-linux-musleabihf">

    ```bash
    PASS_FEATURES=default-musl ./scripts/docker-run.sh builder-armv7-unknown-linux-musleabihf make build
    ```

    </TabItem>
  </Tabs>

  The command above builds a Docker image with Rust toolchain for a Linux target for the
  corresponding architecture using `musl` as the C library, then starts a container from
  this image, and then builds inside the Container. The target binary is located in
  `target/<target triple>/release/vector` like in the previous case.

## Compiling on Windows

The steps to compile Vector on Windows are different from the ones for other operating systems.

1. Install Rust using [`rustup`][urls.rustup]. It would install toolchain for `nightly-x86_64-pc-windows-msvc` target on 64-bit machines by default. If you don't have VC++ build tools, the installer would prompt you to install them.

2. Install [Perl for Windows][urls.perl_windows].

3. In a Rust/MSVC environment (for example, using `x64 Native Tools Command Prompt`) add the binary directory of Perl installed on the previous step to `PATH`. For example, for default installation of  Strawberry Perl it is

    ```
    set PATH=%PATH%;C:\Strawberry\perl\bin
    ```

4. Get Vector's source using `git`:

    <Tabs
      className="mini"
      defaultValue="latest"
      values={[
        { label: 'Latest (0.7.0)', value: 'latest'},
        { label: 'Master', value: 'master'},
      ]}>

    <TabItem value="latest">

    ```
    git clone https://github.com/timberio/vector
    git checkout v0.7.0
    cd vector
    ```

    </TabItem>
    <TabItem value="master">

    ```
    git clone https://github.com/timberio/vector
    cd vector
    ```

    </TabItem>
    </Tabs>

5. Build Vector in release mode:

    ```
    set RUSTFLAGS=-Ctarget-feature=+crt-static
    cargo +nightly-x86_64-pc-windows-msvc build --no-default-features --features default-msvc --release
    ```

6. After these steps a binary `vector.exe` in `target\release` would be created. It can be started by running

    ```
    .\target\release\vector --config config\vector.toml
    ```


[docs.configuration]: /docs/setup/configuration/
[docs.containers]: /docs/setup/installation/containers/
[docs.from_archives]: /docs/setup/installation/manual/from-archives/
[docs.global-options#data-directory]: /docs/reference/global-options/#data-directory
[docs.global-options#data_dir]: /docs/reference/global-options/#data_dir
[docs.glossary#buffer]: /docs/meta/glossary/#buffer
[docs.package_managers]: /docs/setup/installation/package-managers/
[docs.sources.docker]: /docs/reference/sources/docker/
[docs.sources.kafka]: /docs/reference/sources/kafka/
[urls.jemalloc]: https://github.com/jemalloc/jemalloc
[urls.leveldb]: https://github.com/google/leveldb
[urls.lib_rdkafka]: https://github.com/edenhill/librdkafka
[urls.openssl]: https://www.openssl.org/
[urls.perl_windows]: https://www.perl.org/get.html#win32
[urls.rustup]: https://rustup.rs
[urls.zlib]: https://www.zlib.net
